@@ -1,14 +1,19 @@
 core <- c("ggplot2", "tibble", "tidyr", "readr", "purrr", "dplyr", "stringr", "forcats")
 
-core_loaded <- function() {
-  search <- paste0("package:", core)
-  core[search %in% search()]
-}
 core_unloaded <- function() {
   search <- paste0("package:", core)
   core[!search %in% search()]
 }
 
+# Attach the package from the same package library it was
+# loaded from before. https://github.com/tidyverse/tidyverse/issues/171
+same_library <- function(pkg) {
+  loc <- if (pkg %in% loadedNamespaces()) dirname(getNamespaceInfo(pkg, "path"))
+  do.call(
+    "library",
+    list(pkg, lib.loc = loc, character.only = TRUE, warn.conflicts = FALSE)
+  )
+}
 
 tidyverse_attach <- function() {
   to_load <- core_unloaded()
@@ -29,13 +34,16 @@ tidyverse_attach <- function() {
     crayon::col_align(versions, max(crayon::col_nchar(versions)))
   )
 
-  col1 <- 1:floor(length(packages)/2)
+  if (length(packages) %% 2 == 1) {
+    packages <- append(packages, "")
+  }
+  col1 <- seq_len(length(packages) / 2)
   info <- paste0(packages[col1], "     ", packages[-col1])
 
   msg(paste(info, collapse = "\n"), startup = TRUE)
 
   suppressPackageStartupMessages(
-    lapply(to_load, library, character.only = TRUE, warn.conflicts = FALSE)
+    lapply(to_load, same_library)
   )
 
   invisible()
