@@ -6,8 +6,11 @@
   crayon::num_colors(TRUE)
   tidyverse_attach()
 
-  x <- tidyverse_conflicts()
-  msg(tidyverse_conflict_message(x), startup = TRUE)
+  if (!"package:conflicted" %in% search()) {
+    x <- tidyverse_conflicts()
+    msg(tidyverse_conflict_message(x), startup = TRUE)
+  }
+
 }
 
 is_attached <- function(x) {
